@@ -7,7 +7,11 @@
 #  is strictly prohibited.
 #
 
-"""Interact with an Anaml server using the REST API."""
+"""The core of the Python SDK is the `anaml_client.Anaml` class.
+
+Its methods simplify the process of interacting with the REST API and
+accessing data stored in supported external data stores.
+"""
 
 from __future__ import annotations
 
